#!/bin/python

from Simple_Process_REPL.main import init


def main():
    init()


if __name__ == "__main__":
    main()
